@@ -5,7 +5,7 @@ from copy import copy
 from config import Config
 from constants import *
 
-from ffconverter import main_chains
+from ffconverter import main_chains, CHARMM_protomers
 from formats import new_pdb_line, read_gro_line, read_pdb_line
 
 
@@ -65,6 +65,11 @@ def identify_tit_sites(molecules, instanciate_sites=True):
                     molecule = molecules[chain]
                     chain_sites = chain_res[chain]
 
+                    if Config.pypka_params["ffinput"] == "CHARMM":
+                        for can_res, charmm_res in CHARMM_protomers.items():
+                            if resname in charmm_res:
+                                resname = can_res
+
                     if resname in PROTEIN_RESIDUES or resname in TITRABLERESIDUES:
                         if resnumb not in chain_sites:
                             if not chain_res[chain] and not skip_NTR[chain]:
@@ -141,6 +146,8 @@ def check_sites_integrity(molecules, chains_res, useTMPpdb=False):
 
     def check_site(prev_resname, cur_atoms, ter=None):
         def correctResName(resname):
+            if resname in PROTEIN_RESIDUES:
+                return resname
             for res in REGULARTITRATINGRES:
                 if res[0:2] == resname[0:2]:
                     return res
@@ -370,7 +377,7 @@ def check_integrity(resname, res_atoms, ter=False, site=True):
 
     if ter:
         st = "{0}/{1}/sts/{2}tau1.st".format(
-            Config.pypka_params["script_dir"], Config.pypka_params["ffID"], ter
+            Config.pypka_params["ffs_dir"], Config.pypka_params["ffID"], ter
         )
         res_atoms_st = read_anames(st)
         res_atoms, integrity_ter = pop_atoms(res_atoms_st, res_atoms)
@@ -394,7 +401,7 @@ def check_integrity(resname, res_atoms, ter=False, site=True):
             print(("i", integrity))
         if integrity is not False:
             filename = "{0}/{1}/sts/{2}tau1.st".format(
-                Config.pypka_params["script_dir"], Config.pypka_params["ffID"], resname
+                Config.pypka_params["ffs_dir"], Config.pypka_params["ffID"], resname
             )
             res_atoms_st = read_anames(filename)
             res_atoms, integrity = pop_atoms(res_atoms_st, res_atoms)
@@ -427,8 +434,8 @@ def make_delphi_inputfile(f_in, f_out, molecules):
         elif resnumb == ctr_res and aname in Config.pypka_params["CTR_atoms"]:
             resname = "CTR"
             resnumb += TERMINAL_OFFSET
-            if aname == "C":
-                aname = "CT"
+            # if aname == "C":
+            #    aname = "CT"
         return resnumb, resname, aname
 
     def correct_res_names(molecule, resnumb, resname, aname):
@@ -536,7 +543,7 @@ def make_delphi_inputfile(f_in, f_out, molecules):
                 parts = line.split()
                 box = [float(i) for i in parts[1:4]]
 
-    if box == [0.1, 0.1, 0.1]:
+    if box == [1.0, 1.0, 1.0]:
         box = max_box
 
     if Config.pypka_params["box"]:
