@@ -62,9 +62,8 @@ class Tautomer(object):
                        TYRtau2.st has charge set of TY1 and reference TY2
         """
         tau_number = int(self.name[-1]) + 1
-        fname = "{0}/{1}/sts/{2}tau{3}.st".format(
-            Config.pypka_params["script_dir"],
-            Config.pypka_params["ffID"],
+        fname = "{0}/{1}tau{2}.st".format(
+            Config.pypka_params["sts_path"],
             res_name,
             tau_number,
         )
@@ -77,8 +76,8 @@ class Tautomer(object):
                 cols = line.split()
                 if nline > 1:
                     atom_name = cols[1]
-                    if atom_name == "C" and res_name == "CTR":
-                        atom_name = "CT"
+                    # if atom_name == "C" and res_name == "CTR":
+                    #    atom_name = "CT"
                     # elif atom_name in ('O1', 'O2') and res_name == 'CTR':
                     #    atom_name = atom_name[0] + 'T' + atom_name[1]
                     charge_set1[atom_name] = float(cols[-2])
@@ -228,6 +227,7 @@ class Tautomer(object):
             ) = self.getCenteringDetails()
         pdb_text = ""
         crg = "!crg file created by gen_files.awk\n" "atom__resnumbc_charge_\n"
+        siz = "!siz file created by gen_files.awk\n" "atom__res_radius_\n"
         new_atoms = []
 
         lookup_atoms_keys = Config.delphi_params.lookup_atoms.keys()
@@ -261,17 +261,9 @@ class Tautomer(object):
                 aname, resname, round(abs(p_chrgv4[atom_position]), 3), signal
             )
 
-            # for atom_name, atom_id, atom_position in molecule.iterAtoms():
-            #    aID = atom_position + 1
-            #    aname = str(atinf[atom_position].value.split()[0])
-            #    resname = str(atinf[atom_position].value.split()[1])
-            #    resnumb = int(atinf[atom_position].value.split()[2])
-            #    x = float(p_atpos[atom_position][0])
-            #    y = float(p_atpos[atom_position][1])
-            #    z = float(p_atpos[atom_position][2])
-            #    pdb_text += new_pdb_line(aID, aname, resname, resnumb, x, y, z)
-
-            #    print(pdb_text)
+            siz += "{0:<6}{1:<4} {2:0<5} \n".format(
+                aname, resname, round(abs(p_rad3[atom_position]), 3)
+            )
 
             # TODO: quick fix, should be done only once per site
             if Config.delphi_params["pbc_dim"] == 2:
@@ -365,6 +357,10 @@ class Tautomer(object):
                 "P_{1}-{0}.crg".format(self.name, self.site.res_number), "w"
             ) as f_new:
                 f_new.write(crg)
+            with open(
+                "P_{1}-{0}.siz".format(self.name, self.site.res_number), "w"
+            ) as f_new:
+                f_new.write(siz)
 
         return delphimol, acent
 
